<?php

/* --------------------------------------------------------------
   OrderListItem.inc.php 2015-11-06 gm
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2015 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class OrderListItem
 *
 * @category   System
 * @package    Order
 * @subpackage Entities
 */
class OrderListItem
{
	/**
	 * Order ID.
	 * @var int
	 */
	protected $orderId;

	/**
	 * Customer ID.
	 * @var int
	 */
	protected $customerId;
	
	/**
	 * Customer name.
	 * @var string
	 */
	protected $customerName;
	
	/**
	 * Total summary.
	 * @var float
	 */
	protected $totalSum;
	
	/**
	 * Payment type.
	 * @var string
	 */
	protected $paymentType;
	
	/**
	 * Shipping type.
	 * @var string
	 */
	protected $shippingType;
	
	/**
	 * Purchase date time.
	 * @var DateTime
	 */
	protected $purchaseDateTime;
	
	/**
	 * Order status ID.
	 * @var int
	 */
	protected $orderStatusId;
	
	/**
	 * Order status name.
	 * @var string
	 */
	protected $orderStatusName;
	
	
	/**
	 * OrderListItem Constructor
	 *
	 * @param IdType            $orderId          Order ID.
	 * @param IdType            $customerId       Customer ID.
	 * @param StringType        $customerName     Customer name.
	 * @param DecimalType       $totalSum         Total summary.
	 * @param OrderPaymentType  $paymentType      Payment type.
	 * @param OrderShippingType $shippingType     Shipping type.
	 * @param DateTime          $purchaseDateTime Purchase date time.
	 * @param IdType            $orderStatusId    Order status ID.
	 * @param StringType        $orderStatusName  Order status name.
	 */
	public function __construct(IdType $orderId,
	                            IdType $customerId,
	                            StringType $customerName,
	                            DecimalType $totalSum,
	                            OrderPaymentType $paymentType,
	                            OrderShippingType $shippingType,
	                            DateTime $purchaseDateTime,
	                            IdType $orderStatusId,
	                            StringType $orderStatusName)
	{
		$this->orderId          = $orderId->asInt();
		$this->customerId       = $customerId->asInt();
		$this->customerName     = $customerName->asString();
		$this->totalSum         = $totalSum->asDecimal();
		$this->paymentType      = $paymentType;
		$this->shippingType     = $shippingType;
		$this->purchaseDateTime = $purchaseDateTime;
		$this->orderStatusId    = $orderStatusId->asInt();
		$this->orderStatusName  = $orderStatusName->asString();
	}
	
	
	/**
	 * Returns the order ID.
	 * @return int Order ID.
	 */
	public function getOrderId()
	{
		return $this->orderId;
	}
	
	
	/**
	 * Returns the customer ID.
	 * @return int Customer ID.
	 */
	public function getCustomerId()
	{
		return $this->customerId;
	}
	
	
	/**
	 * Returns the customer name.
	 * @return string Customer name.
	 */
	public function getCustomerName()
	{
		return $this->customerName;
	}
	
	
	/**
	 * Returns the total summary.
	 * @return float Total summary.
	 */
	public function getTotalSum()
	{
		return $this->totalSum;
	}
	
	
	/**
	 * Returns the payment type.
	 * @return OrderPaymentType Payment type.
	 */
	public function getPaymentType()
	{
		return $this->paymentType;
	}
	
	
	/**
	 * Returns the shipping type.
	 * @return OrderShippingType Shipping type.
	 */
	public function getShippingType()
	{
		return $this->shippingType;
	}
	
	
	/**
	 * Purchase date time.
	 * @return DateTime Purchase date time.
	 */
	public function getPurchaseDateTime()
	{
		return $this->purchaseDateTime;
	}
	
	
	/**
	 * Returns the order status ID.
	 * @return int Order status ID.
	 */
	public function getOrderStatusId()
	{
		return $this->orderStatusId;
	}
	
	
	/**
	 * Returns the order status name.
	 * @return string Order status name.
	 */
	public function getOrderStatusName()
	{
		return $this->orderStatusName;
	}
}